"""
dropthe - Python SDK for DropThe.org entity data.

Access 1.9M+ entities across movies, people, companies, crypto, games,
universities, and more — connected by 2.18M knowledge graph links.

    >>> import dropthe
    >>> movies = dropthe.movies()
    >>> movies[0]
    {'name': 'Inception', 'rating': 8.4, 'year': 2010, ...}

    >>> dropthe.search("Bitcoin")
    [{'name': 'Bitcoin', 'type': 'cryptocurrencies', 'slug': 'bitcoin'}, ...]

Full docs: https://dropthe.org/good/methodology/
"""

__version__ = "0.1.0"
__author__ = "DropThe"
__url__ = "https://dropthe.org"

from dropthe.client import DropTheClient
from dropthe.datasets import (
    movies,
    crypto,
    companies,
    games,
    universities,
    streaming,
)
from dropthe.search import search, entity

__all__ = [
    "DropTheClient",
    "movies",
    "crypto",
    "companies",
    "games",
    "universities",
    "streaming",
    "search",
    "entity",
]
